/*******************************************************************\

Module: Decision Procedure Interface

Author: Daniel Kroening, kroening@kroening.com

\*******************************************************************/

#include <cassert>

#include "decision_procedure.h"

/*******************************************************************\

Function: decision_proceduret::in_core

  Inputs:

 Outputs:

 Purpose:

\*******************************************************************/

bool decision_proceduret::in_core(const exprt &expr)
{
  assert(false);
  return true;
}
